''' 
Meshtastic MQTT Interface - A lightweight Python library for parsing Meshtastic MQTT messages
'''

from .client import MeshtasticMQTT

__version__ = "1.0.4"
__author__  = "acidvegas"
__license__ = "ISC" 